% This is a demo to use DPHEM with Matlab
% ---
% If you use this code, please cite our paper:
%   Lei Yu, Tianyu Yang, and Antoni B. Chan. "Density Preserving Hierarchical EM Algorithm: Simplifying 
%   Gaussian Mixture Models for Approximate Inference." TPAMI 2019
% ---
% Copyright (c) 2019-04-30
% Lei Yu, Antoni B. Chan
% City University of Hong Kong 
%
% v0.1


clc;
clear all;

% basegmm = generate_basegmm();
ldfile = load('example_basegmm.mat');
basegmm = ldfile.basegmm;


% For pimode: 
%   - 'original' for HEM and 'preserve' for DPHEM 
% For initmode: 
%   - 'fix' : with a given initgmm
%   - 'random' : randomly initialize the reducedgmm
%   - 'wtkmeans': initialize the reducedgmm with weighted kmeans of 
%                 components in the basegmm
%   - 'split': start from single component and splitting components until 
%              target reduced number reached through the optimization
opt.pimode = 'preserve';   
opt.initmode = 'random';
tagk = 20;  % target number of reduced GMM

reducedgmm = gmm_dphem_learn(basegmm,tagk,opt);

figure;
gmm_plot2d_surf(basegmm);
title(sprintf('Base GMM with %d components',basegmm.K));

figure;
gmm_plot2d_surf(reducedgmm);
title(sprintf('Reduced GMM with %d components',reducedgmm.K));



